@@ -1,5 +1,6 @@
 /*
- * LALVCSInfo.h - LAL VCS Information Header
+ * Copyright (C) 2014, 2016 Karl Wette
+ * Copyright (C) 2009-2013 Adam Mercer
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +16,10 @@
  * along with with program; see the file COPYING. If not, write to the
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  * MA 02111-1307 USA
- *
- * Copyright (C) 2009-2013 Adam Mercer
- * Copyright (C) 2014 Karl Wette
+ */
+
+/*
+ * LALVCSInfo.h - LAL VCS Information Header
  */
 
 /** \cond DONT_DOXYGEN */
@@ -33,37 +35,19 @@
 extern "C" {
 #endif
 
-/* VCS information defines */
-#define LAL_NAME "LAL"
-#define LAL_VCS_ID "b5ca2b6bee576a61027135359046e758ccc4eadf"
-#define LAL_VCS_DATE "2016-10-10 17:31:34 +0000"
+/* VCS information */
+#define LAL_VCS_ID "ea18729b27507187e1b8cbbec723746de32aa2ce"
+#define LAL_VCS_DATE "2017-02-6 18:15:56 +0000"
 #define LAL_VCS_BRANCH "None"
-#define LAL_VCS_TAG "lal-v6.17.0"
+#define LAL_VCS_TAG "lal-v6.18.0"
 #define LAL_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
 #define LAL_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
+#define LAL_VCS_CLEAN "CLEAN"
 #define LAL_VCS_STATUS "CLEAN: All modifications committed"
 
-/* Identable VCS information defines */
-#define LAL_VCS_IDENT_ID "$" "LALId: b5ca2b6bee576a61027135359046e758ccc4eadf " "$"
-#define LAL_VCS_IDENT_DATE "$" "LALDate: 2016-10-10 17:31:34 +0000 " "$"
-#define LAL_VCS_IDENT_BRANCH "$" "LALBranch: None " "$"
-#define LAL_VCS_IDENT_TAG "$" "LALTag: lal-v6.17.0 " "$"
-#define LAL_VCS_IDENT_AUTHOR "$" "LALAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LAL_VCS_IDENT_COMMITTER "$" "LALCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
-#define LAL_VCS_IDENT_STATUS "$" "LALStatus: CLEAN: All modifications committed " "$"
-
-/* Header VCS information structure */
-static const LALVCSInfo lalVCSInfoHeader = { \
-  LAL_NAME, \
-  LAL_VERSION, \
-  LAL_VCS_ID, \
-  LAL_VCS_DATE, \
-  LAL_VCS_BRANCH, \
-  LAL_VCS_TAG, \
-  LAL_VCS_AUTHOR, \
-  LAL_VCS_COMMITTER, \
-  LAL_VCS_STATUS \
-};
+/* VCS header/library mismatch link check function */
+#define LAL_VCS_LINK_CHECK LAL_CLEAN_ea18729b27507187e1b8cbbec723746de32aa2ce_VCS_HEADER_LIBRARY_MISMATCH
+void LAL_VCS_LINK_CHECK(void);
 
 #ifdef __cplusplus
 }
@@ -72,7 +56,3 @@ static const LALVCSInfo lalVCSInfoHeader = { \
 #endif /* _LALVCSINFOHEADER_H */
 
 /** \endcond */
-
-/*
- * vim: tw=0 ts=2 et
- */
