@@ -70,8 +70,10 @@ typedef enum {
   UVAR_TYPE_START=0, 		// internal start marker for range checking
 
   UVAR_TYPE_BOOLEAN, 		// boolean
-  UVAR_TYPE_INT4,    		// 4-byte integer
-  UVAR_TYPE_INT8,    		// 8-byte integer
+  UVAR_TYPE_INT4,    		// 4-byte signed integer
+  UVAR_TYPE_INT8,    		// 8-byte signed integer
+  UVAR_TYPE_UINT4,    		// 4-byte unsigned integer
+  UVAR_TYPE_UINT8,    		// 8-byte unsigned integer
   UVAR_TYPE_REAL8,   		// 8-byte float
   UVAR_TYPE_EPOCH,   		// time 'epoch', specified in either GPS or MJD(TT) format, translated into GPS
   UVAR_TYPE_RAJ,     		// sky equatorial longitude (aka right-ascencion or RA), in either radians or hours:minutes:seconds format, translated into radians
@@ -83,9 +85,10 @@ typedef enum {
   UVAR_TYPE_RAJRange,		// range of RAJ values
   UVAR_TYPE_DECJRange,		// range of DECJ values
 
-  UVAR_TYPE_STRINGVector,	// list of comma-separated strings
-  UVAR_TYPE_REAL8Vector,	// list of comma-separated REAL8's
   UVAR_TYPE_INT4Vector,		// list of comma-separated INT4's
+  UVAR_TYPE_UINT4Vector,	// list of comma-separated UINT4's
+  UVAR_TYPE_REAL8Vector,	// list of comma-separated REAL8's
+  UVAR_TYPE_STRINGVector,	// list of comma-separated strings
 
   UVAR_TYPE_END      	// internal end marker for range checking
 } UserVarType;
@@ -98,7 +101,7 @@ typedef struct tagLALUserVariable {
   UserVarType type;			// variable type: BOOLEAN, INT4, REAL8, ...
   CHAR optchar;				// cmd-line character
   CHAR help[2048];			// help-string
-  void *varp;				// pointer to the actual C-variable
+  void *cvar;				// pointer to the actual C-variable
   UserVarCategory category;		// category (optional, required, developer, ... )
   BOOLEAN was_set;			// was this set by the user: 0=no, 1=via cfg-file, 2=via cmdline
   struct tagLALUserVariable *next; 	// linked list
@@ -115,6 +118,8 @@ static void fprint_wrapped( FILE *f, int line_width, const char *prefix, char *t
 DEFN_REGISTER_UVAR(BOOLEAN,BOOLEAN);
 DEFN_REGISTER_UVAR(INT4,INT4);
 DEFN_REGISTER_UVAR(INT8,INT8);
+DEFN_REGISTER_UVAR(UINT4,UINT4);
+DEFN_REGISTER_UVAR(UINT8,UINT8);
 DEFN_REGISTER_UVAR(REAL8,REAL8);
 DEFN_REGISTER_UVAR(RAJ,REAL8);
 DEFN_REGISTER_UVAR(DECJ,REAL8);
@@ -126,23 +131,24 @@ DEFN_REGISTER_UVAR(EPOCHRange,LIGOTimeGPSRange);
 DEFN_REGISTER_UVAR(RAJRange,REAL8Range);
 DEFN_REGISTER_UVAR(DECJRange,REAL8Range);
 
-DEFN_REGISTER_UVAR(STRINGVector,LALStringVector*);
-DEFN_REGISTER_UVAR(REAL8Vector,REAL8Vector*);
 DEFN_REGISTER_UVAR(INT4Vector,INT4Vector*);
+DEFN_REGISTER_UVAR(UINT4Vector,UINT4Vector*);
+DEFN_REGISTER_UVAR(REAL8Vector,REAL8Vector*);
+DEFN_REGISTER_UVAR(STRINGVector,LALStringVector*);
 
 // ----- define helper types for casting
-typedef int (*parserT)(void*, const char*);
-typedef void (*destructorT)(void*);
-typedef char *(*printerT)(const void*);
+typedef void (*destructorT)(void *cvar);
+typedef int (*parserT)(void *cvar, const char *valstr);
+typedef char *(*printerT)(const void *cvar);
 
 // ----- handy macro to simplify adding 'regular' entries for new UTYPES into UserVarTypeMap
 #define REGULAR_MAP_ENTRY(UTYPE,DESTRUCTOR,FORMATHELP) \
   [UVAR_TYPE_##UTYPE] = { \
     .name = #UTYPE, \
-    .format_help = FORMATHELP, \
+    .destructor = (destructorT)DESTRUCTOR, \
     .parser = (parserT)XLALParseStringValueAs##UTYPE, \
     .printer = (printerT)XLALPrintStringValueOf##UTYPE, \
-    .destructor = (destructorT)DESTRUCTOR \
+    .format_help_str = FORMATHELP, \
   }
 
 // ---------- HOWTO add new UserInput variable types ----------
@@ -162,33 +168,40 @@ typedef char *(*printerT)(const void*);
 static const struct
 {
   const char *const name;			///< type name
-  const char *const format_help;		///< help string describing format of user variable
-  int (*parser)(void*, const char*);		///< parser function to parse string as this type
-  char *(*printer)(const void *);		///< 'printer' function returning string value for given type
-  void (*destructor)(void*);			///< destructor for this variable type, NULL if none required
+  destructorT destructor;			///< destructor for this variable type, NULL if none required
+  parserT parser;				///< parser function to parse string as this type
+  printerT printer;				///< 'printer' function returning string value for given type
+  const char *const format_help_str;   		///< help string describing format of user variable
 } UserVarTypeMap[UVAR_TYPE_END]
 = {
   // either use 'manual' entries of the form
-  // [UVAR_TYPE_\<UTYPE\>] = { "\<UTYPE\>",	(parserT)XLALParseStringValueAs\<UTYPE\>, (printerT)XLALPrintStringValueOf\<UTYPE\>, (destructorT)XLALDestroy\<UTYPE\> },
+  //   [UVAR_TYPE_\<UTYPE\>] = {
+  //     .name = "\<UTYPE\>", .destructor = (destructorT)XLALDestroy\<UTYPE\>, .format_help_str = "=help string for \<UTYPE\>",
+  //     .parser = (parserT)XLALParseStringValueAs\<UTYPE\>, .printer = (printerT)XLALPrintStringValueOf\<UTYPE\>,
+  //   },
   // or the convenience macro for cases using 'standard' function names and API
-  // REGULAR_MAP_ENTRY ( \<UTYPE\>, XLALDestroy\<UTYPE\> ),
-  REGULAR_MAP_ENTRY ( BOOLEAN, NULL, "[TRUE|FALSE | YES|NO | 1|0]" ),
-  REGULAR_MAP_ENTRY ( INT4, NULL, "<4-byte integer>" ),
-  REGULAR_MAP_ENTRY ( INT8, NULL, "<8-byte integer>" ),
-  REGULAR_MAP_ENTRY ( REAL8, NULL, "<8-byte real>" ),
-  REGULAR_MAP_ENTRY ( STRING, XLALFree, "<string>" ),
-  REGULAR_MAP_ENTRY ( EPOCH, NULL, "<seconds>[.<nano-seconds>][GPS|MJD]" ),
-  REGULAR_MAP_ENTRY ( RAJ, NULL, "<radians>|<hours>:<minutes>:<seconds>" ),
-  REGULAR_MAP_ENTRY ( DECJ, NULL, "<radians>|<degrees>:<minutes>:<seconds>" ),
+  //   REGULAR_MAP_ENTRY ( \<UTYPE\>, XLALDestroy\<UTYPE\>, "=help string for \<UTYPE\>" ),
 
-  REGULAR_MAP_ENTRY ( REAL8Range, NULL, "<start>[,<end>|/<band>|~<plus-minus>] where <>=<8-byte real>" ),
-  REGULAR_MAP_ENTRY ( EPOCHRange, NULL, "<start>[,<end>|/<band>|~<plus-minus>] where <>=<seconds>[.<nano-seconds>][GPS|MJD]" ),
-  REGULAR_MAP_ENTRY ( RAJRange, NULL, "<start>[,<end>|/<band>|~<plus-minus>] where <>=<radians>|<hours>:<minutes>:<seconds>" ),
-  REGULAR_MAP_ENTRY ( DECJRange, NULL, "<start>[,<end>|/<band>|~<plus-minus>] where <>=<radians>|<degrees>:<minutes>:<seconds>" ),
+  REGULAR_MAP_ENTRY ( BOOLEAN, NULL, "[=(TRUE|FALSE)|(YES|NO)|(1|0)]" ),
+  REGULAR_MAP_ENTRY ( INT4, NULL, "=<4-byte signed integer>" ),
+  REGULAR_MAP_ENTRY ( INT8, NULL, "=<8-byte signed integer>" ),
+  REGULAR_MAP_ENTRY ( UINT4, NULL, "=<4-byte unsigned integer>" ),
+  REGULAR_MAP_ENTRY ( UINT8, NULL, "=<8-byte unsigned integer>" ),
+  REGULAR_MAP_ENTRY ( REAL8, NULL, "=<8-byte real>" ),
+  REGULAR_MAP_ENTRY ( STRING, XLALFree, "=<string>" ),
+  REGULAR_MAP_ENTRY ( EPOCH, NULL, "=<seconds>[.<frac-seconds>][GPS] | <days>[.<frac-days>]MJD" ),
+  REGULAR_MAP_ENTRY ( RAJ, NULL, "=<radians>|<hours>:<minutes>:<seconds>" ),
+  REGULAR_MAP_ENTRY ( DECJ, NULL, "=<radians>|<degrees>:<minutes>:<seconds>" ),
 
-  REGULAR_MAP_ENTRY ( STRINGVector, XLALDestroyStringVector, "<string>,..." ),
-  REGULAR_MAP_ENTRY ( REAL8Vector, XLALDestroyREAL8Vector, "<8-byte real>,..." ),
-  REGULAR_MAP_ENTRY ( INT4Vector, XLALDestroyINT4Vector, "<4-byte integer>,..." )
+  REGULAR_MAP_ENTRY ( REAL8Range, NULL, "=<start>[,<end>|/<band>|~<plus-minus>] where <>=<8-byte real>" ),
+  REGULAR_MAP_ENTRY ( EPOCHRange, NULL, "=<start>[,<end>|/<band>|~<plus-minus>] where <>=<seconds>[.<frac-seconds>][GPS] | <days>[.<frac-days>]MJD" ),
+  REGULAR_MAP_ENTRY ( RAJRange, NULL, "=<start>[,<end>|/<band>|~<plus-minus>] where <>=<radians>|<hours>:<minutes>:<seconds>" ),
+  REGULAR_MAP_ENTRY ( DECJRange, NULL, "=<start>[,<end>|/<band>|~<plus-minus>] where <>=<radians>|<degrees>:<minutes>:<seconds>" ),
+
+  REGULAR_MAP_ENTRY ( INT4Vector, XLALDestroyINT4Vector, "=<4-byte signed integer>,..." ),
+  REGULAR_MAP_ENTRY ( UINT4Vector, XLALDestroyUINT4Vector, "=<4-byte unsigned integer>,..." ),
+  REGULAR_MAP_ENTRY ( REAL8Vector, XLALDestroyREAL8Vector, "=<8-byte real>,..." ),
+  REGULAR_MAP_ENTRY ( STRINGVector, XLALDestroyStringVector, "=<string>,..." ),
 };
 
 
@@ -267,7 +280,7 @@ XLALRegisterUserVar ( void *cvar,		/**< pointer to the actual C-variabe to link
   // fill in entry values
   ptr->type 	= type;
   ptr->optchar 	= optchar;
-  ptr->varp 	= cvar;
+  ptr->cvar 	= cvar;
   ptr->category = category;
 
   return XLAL_SUCCESS;
@@ -291,8 +304,8 @@ XLALDestroyUserVars ( void )
       // is there a destructor function registered for this type?
       if ( UserVarTypeMap [ ptr->type ].destructor != NULL )
         {
-          UserVarTypeMap [ ptr->type ].destructor ( *(CHAR**)ptr->varp );
-          *(CHAR**)ptr->varp = NULL;
+          UserVarTypeMap [ ptr->type ].destructor ( *(CHAR**)ptr->cvar );
+          *(CHAR**)ptr->cvar = NULL;
         }
 
       /* free list-entry behind us (except for the head) */
@@ -436,11 +449,17 @@ XLALUserVarReadCmdline ( BOOLEAN *should_exit, int argc, char *argv[] )
             }
 
 	  if ( LALoptarg == NULL ) { // if no argument given, defaults to TRUE
-            *(BOOLEAN*)(ptr->varp) = TRUE;
+            *(BOOLEAN*)(ptr->cvar) = TRUE;
           } else {
-            if ( UserVarTypeMap [ ptr->type ].parser( ptr->varp, LALoptarg ) != XLAL_SUCCESS )
+            if ( LALoptarg == NULL || strlen(LALoptarg) == 0 )
               {
-                XLALPrintError( "\n%s: could not parse value given to option " UVAR_FMT "\n\n", program_name, ptr->name );
+                XLALPrintError( "\n%s: no value given to option " UVAR_FMT "\n\n", program_name, ptr->name );
+                *should_exit = 1;
+                return XLAL_SUCCESS;
+              }
+            if ( UserVarTypeMap [ ptr->type ].parser( ptr->cvar, LALoptarg ) != XLAL_SUCCESS )
+              {
+                XLALPrintError( "\n%s: could not parse value '%s' given to option " UVAR_FMT "\n\n", program_name, LALoptarg, ptr->name );
                 *should_exit = 1;
                 return XLAL_SUCCESS;
               }
@@ -451,12 +470,18 @@ XLALUserVarReadCmdline ( BOOLEAN *should_exit, int argc, char *argv[] )
           // all other UVAR_TYPE_ types can be handled canonically: first destroy previous value, the parse new one
           if ( UserVarTypeMap [ ptr->type ].destructor != NULL )
             {
-              UserVarTypeMap [ ptr->type ].destructor( *(char**)ptr->varp );
-              *(char**)ptr->varp = NULL;
+              UserVarTypeMap [ ptr->type ].destructor( *(char**)ptr->cvar );
+              *(char**)ptr->cvar = NULL;
             } // if a destructor was registered
-          if ( UserVarTypeMap [ ptr->type ].parser( ptr->varp, LALoptarg ) != XLAL_SUCCESS )
+          if ( LALoptarg == NULL || strlen(LALoptarg) == 0 )
             {
-              XLALPrintError( "\n%s: could not parse value given to option " UVAR_FMT "\n\n", program_name, ptr->name );
+              XLALPrintError( "\n%s: no value given to option " UVAR_FMT "\n\n", program_name, ptr->name );
+              *should_exit = 1;
+              return XLAL_SUCCESS;
+            }
+          if ( UserVarTypeMap [ ptr->type ].parser( ptr->cvar, LALoptarg ) != XLAL_SUCCESS )
+            {
+              XLALPrintError( "\n%s: could not parse value '%s' given to option " UVAR_FMT "\n\n", program_name, LALoptarg, ptr->name );
               *should_exit = 1;
               return XLAL_SUCCESS;
             }
@@ -537,12 +562,18 @@ XLALUserVarReadCfgfile ( BOOLEAN *should_exit, const CHAR *cfgfile )
           // destroy previous value, is applicable, then parse new one
           if ( UserVarTypeMap [ ptr->type ].destructor != NULL )
             {
-              UserVarTypeMap [ ptr->type ].destructor( *(char**)ptr->varp );
-              *(char**)ptr->varp = NULL;
+              UserVarTypeMap [ ptr->type ].destructor( *(char**)ptr->cvar );
+              *(char**)ptr->cvar = NULL;
             } // if a destructor was registered
-          if ( UserVarTypeMap [ ptr->type ].parser( ptr->varp, valString ) != XLAL_SUCCESS )
+          if ( valString == NULL || strlen(valString) == 0 )
             {
-              XLALPrintError( "\n%s: could not parse value given to option " UVAR_FMT "\n\n", program_name, ptr->name );
+              XLALPrintError( "\n%s: no value given to option " UVAR_FMT "\n\n", program_name, ptr->name );
+              *should_exit = 1;
+              return XLAL_SUCCESS;
+            }
+          if ( UserVarTypeMap [ ptr->type ].parser( ptr->cvar, valString ) != XLAL_SUCCESS )
+            {
+              XLALPrintError( "\n%s: could not parse value '%s' given to option " UVAR_FMT "\n\n", program_name, valString, ptr->name );
               *should_exit = 1;
               return XLAL_SUCCESS;
             }
@@ -790,7 +821,7 @@ XLALUserVarPrintHelp ( FILE *file )
               fprintf( f, "--%s", ptr->name );
               if ( print_format_help )
                 {
-                  fprintf( f, "=%s", UserVarTypeMap [ ptr->type ].format_help );
+                  fprintf( f, "%s", UserVarTypeMap [ ptr->type ].format_help_str );
                 }
               if ( print_default_value )
                 {
@@ -805,7 +836,7 @@ XLALUserVarPrintHelp ( FILE *file )
                   else
                     {
                       char *valstr;
-                      XLAL_CHECK( (valstr = UserVarTypeMap [ ptr->type ].printer( ptr->varp )) != NULL, XLAL_EFUNC );
+                      XLAL_CHECK( (valstr = UserVarTypeMap [ ptr->type ].printer( ptr->cvar )) != NULL, XLAL_EFUNC );
                       fprintf( f, " [default: %s]",  valstr );
                       XLALFree( valstr );
                     }
@@ -969,7 +1000,7 @@ XLALUserVarWasSet ( const void *cvar )
   LALUserVariable *ptr = &UVAR_vars;
   while ( (ptr = ptr->next) != NULL )
     {
-      if ( ptr->varp == cvar) {
+      if ( ptr->cvar == cvar) {
         break;
       }
     } // while ptr = ptr->next
@@ -1033,7 +1064,7 @@ XLALUserVarGetLog ( UserVarLogFormat format 	/**< output format: return as confi
       }
 
       CHAR *valstr;
-      XLAL_CHECK_NULL ( (valstr = UserVarTypeMap [ ptr->type ].printer( ptr->varp )) != NULL, XLAL_EFUNC );
+      XLAL_CHECK_NULL ( (valstr = UserVarTypeMap [ ptr->type ].printer( ptr->cvar )) != NULL, XLAL_EFUNC );
 
       char append[256];
       switch (format)
@@ -1064,161 +1095,3 @@ XLALUserVarGetLog ( UserVarLogFormat format 	/**< output format: return as confi
   return record;
 
 } // XLALUserVarGetLog()
-
-/* ========== DEPRECATED LAL INTERFACE FUNCTIONS, which have been replaced by XLAL functions,
- * These functions are just wrappers around the XLAL functions
- */
-#define USERINPUTH_EXLAL        1
-#define USERINPUTH_MSGEXLAL	"Failure in XLAL function"
-
-/** \deprecated us XLALDestroyUserVars() instead */
-void
-LALDestroyUserVars (LALStatus *status)
-{
-  INITSTATUS(status);
-  XLALDestroyUserVars();
-  RETURN (status);
-} // LALDestroyUserVars()
-
-
-/** \deprecated use XLALUserVarReadCmdline() instead */
-void
-LALUserVarReadCmdline (LALStatus *status, BOOLEAN *should_exit, int argc, char *argv[])
-{
-  INITSTATUS(status);
-  if ( XLALUserVarReadCmdline(should_exit, argc, argv) != XLAL_SUCCESS ) {
-    XLALPrintError ("Call to XLALUserVarReadCmdline() failed with code %d\n", xlalErrno );
-    ABORT ( status,  USERINPUTH_EXLAL,  USERINPUTH_MSGEXLAL );
-  }
-  RETURN (status);
-} // LALUserVarReadCmdline()
-
-/** \deprecated use XLALUserVarReadAllInput() instead */
-void
-LALUserVarReadAllInput (LALStatus *status, BOOLEAN *should_exit, int argc, char *argv[])
-{
-  INITSTATUS(status);
-  if ( XLALUserVarReadAllInput ( should_exit, argc, argv ) != XLAL_SUCCESS ) {
-    XLALPrintError ( "XLALUserVarReadAllInput() failed with code %d\n", xlalErrno );
-    ABORT ( status,  USERINPUTH_EXLAL,  USERINPUTH_MSGEXLAL );
-  }
-  RETURN (status);
-} // LALReadUserInput()
-
-/** \deprecated use XLALUserVarWasSet() instead */
-INT4
-LALUserVarWasSet (const void *cvar)
-{
-  return (XLALUserVarWasSet(cvar));
-}
-
-/** \deprecated use XLALUserVarGetLog() instead */
-void
-LALUserVarGetLog (LALStatus *status, CHAR **logstr,  UserVarLogFormat format)
-{
-  INITSTATUS(status);
-  if ( ((*logstr) = XLALUserVarGetLog ( format )) == NULL ) {
-    XLALPrintError ("UserVarLogFormat() failed.\n" );
-    ABORT (status, USERINPUTH_EXLAL, USERINPUTH_MSGEXLAL);
-  }
-  RETURN (status);
-} /* LALUserVarGetLog() */
-
-/** \deprecated use XLALRegisterREALUserVar() instead */
-void
-LALRegisterREALUserVar (LALStatus *status,
-			const CHAR *name,
-			CHAR optchar,
-			UserVarCategory category,
-			const CHAR *helpstr,
-			REAL8 *cvar)
-{
-  INITSTATUS(status);
-  if ( XLALRegisterUserVar ( cvar, name, UVAR_TYPE_REAL8, optchar, category, helpstr ) != XLAL_SUCCESS ) {
-    XLALPrintError ("Call to XLALRegisterUserVar() failed: %d\n", xlalErrno );
-    ABORT ( status, USERINPUTH_EXLAL, USERINPUTH_MSGEXLAL );
-  }
-  RETURN(status);
-}
-
-/** \deprecated use XLALRegisterINTUserVar() instead */
-void
-LALRegisterINTUserVar (LALStatus *status,
-		       const CHAR *name,
-		       CHAR optchar,
-		       UserVarCategory category,
-		       const CHAR *helpstr,
-		       INT4 *cvar)
-{
-  INITSTATUS(status);
-  if ( XLALRegisterUserVar ( cvar, name, UVAR_TYPE_INT4, optchar, category, helpstr ) != XLAL_SUCCESS ) {
-    XLALPrintError ("Call to XLALRegisterUserVar() failed: %d\n", xlalErrno );
-    ABORT ( status, USERINPUTH_EXLAL, USERINPUTH_MSGEXLAL );
-  }
-  RETURN(status);
-}
-
-/** \deprecated use XLALRegisterBOOLUserVar() instead */
-void
-LALRegisterBOOLUserVar (LALStatus *status,
-			const CHAR *name,
-			CHAR optchar,
-			UserVarCategory category,
-			const CHAR *helpstr,
-			BOOLEAN *cvar)
-{
-  INITSTATUS(status);
-  if ( XLALRegisterUserVar ( cvar, name, UVAR_TYPE_BOOLEAN, optchar, category, helpstr ) != XLAL_SUCCESS ) {
-    XLALPrintError ("Call to XLALRegisterUserVar() failed: %d\n", xlalErrno );
-    ABORT ( status, USERINPUTH_EXLAL, USERINPUTH_MSGEXLAL );
-  }
-  RETURN(status);
-}
-
-/** \deprecated use XLALRegisterSTRINGUserVar() instead */
-void
-LALRegisterSTRINGUserVar (LALStatus *status,
-			  const CHAR *name,
-			  CHAR optchar,
-			  UserVarCategory category,
-			  const CHAR *helpstr,
-			  CHAR **cvar)
-{
-  INITSTATUS(status);
-  if ( XLALRegisterUserVar ( cvar, name, UVAR_TYPE_STRING, optchar, category, helpstr ) != XLAL_SUCCESS ) {
-    XLALPrintError ("Call to XLALRegisterUserVar() failed: %d\n", xlalErrno );
-    ABORT ( status, USERINPUTH_EXLAL, USERINPUTH_MSGEXLAL );
-  }
-  RETURN(status);
-}
-
-/** \deprecated use XLALRegisterSTRINGVectorUserVar() instead */
-void
-LALRegisterLISTUserVar (LALStatus *status,
-			const CHAR *name,
-			CHAR optchar,
-			UserVarCategory category,
-			const CHAR *helpstr,
-			LALStringVector **cvar)
-{
-  INITSTATUS(status);
-  if ( XLALRegisterUserVar ( cvar, name, UVAR_TYPE_STRINGVector, optchar, category, helpstr ) != XLAL_SUCCESS ) {
-    XLALPrintError ("Call to XLALRegisterUserVar() failed: %d\n", xlalErrno );
-    ABORT ( status, USERINPUTH_EXLAL, USERINPUTH_MSGEXLAL );
-  }
-  RETURN(status);
-}
-
-/** \deprecated use XLALUserVarReadCfgfile() instead */
-void
-LALUserVarReadCfgfile (LALStatus *status,
-		       BOOLEAN *should_exit,
-		       const CHAR *cfgfile) 	   /* name of config-file */
-{
-
-  INITSTATUS(status);
-  if ( XLALUserVarReadCfgfile ( should_exit, cfgfile ) != XLAL_SUCCESS ) {
-    ABORT ( status, USERINPUTH_EXLAL, USERINPUTH_MSGEXLAL );
-  }
-  RETURN (status);
-} // LALUserVarReadCfgfile()
