@@ -7,6 +7,10 @@ import datetime
 import numpy
 expected_exception = False
 
+# return if 'x' has both value 'v' and type 't'
+def is_value_and_type(x, v, t):
+    return x == v and type(x) is t
+
 # turn NumPy's ComplexWarning into an error, if available
 if hasattr(numpy, "ComplexWarning"):
     warnings.simplefilter("error", numpy.ComplexWarning)
@@ -991,6 +995,20 @@ del ap
 lal.CheckMemoryLeaks()
 print("PASSED dynamic array of pointers access")
 
+## check typemaps for strings and double pointers
+print("checking typemaps for strings and double pointers ...")
+sts = lal.swig_lal_test_struct()
+ptr_ptr, ptr_null_ptr, null_ptr_ptr = lal.swig_lal_test_typemaps_string_ptrptr("abcde", "", None, sts, 0, None)
+assert(ptr_ptr == sts)
+assert(ptr_null_ptr == sts)
+assert(null_ptr_ptr == None)
+del sts
+del ptr_ptr
+del ptr_null_ptr
+del null_ptr_ptr
+lal.CheckMemoryLeaks()
+print("PASSED typemaps for strings and double pointers")
+
 # check 'tm' struct conversions
 print("checking 'tm' struct conversions ...")
 gps0 = 989168284
@@ -1016,36 +1034,36 @@ print("PASSED 'tm' struct conversions")
 print("checking LIGOTimeGPS operations ...")
 from lal import LIGOTimeGPS
 t0 = LIGOTimeGPS()
-assert(isinstance(LIGOTimeGPS(t0), LIGOTimeGPS))
-assert(t0 == 0 and isinstance(t0, LIGOTimeGPS))
+assert(type(LIGOTimeGPS(t0)) is LIGOTimeGPS)
+assert(is_value_and_type(t0, 0, LIGOTimeGPS))
 assert(t0 != None and not t0 is None)
 t1 = LIGOTimeGPS(10.5)
 t2 = LIGOTimeGPS(10, 500000000)
 assert(not t0 and t1 and t2)
-assert(t1 == t2 and isinstance(t1, LIGOTimeGPS))
+assert(is_value_and_type(t1, t2, LIGOTimeGPS))
 t3 = +t1
 t3 = -t2
 assert(t1 == t2 and t1 >= t2 and t2 >= t1)
 assert(abs(-t1) == t1)
 assert(float(t1) == 10.5)
-assert(t1 + 3.5 == 14 and isinstance(t1 + 3.5, LIGOTimeGPS))
-assert(3.5 + t1 == 14 and isinstance(3.5 + t1, LIGOTimeGPS))
+assert(is_value_and_type(t1 + 3.5, 14, LIGOTimeGPS))
+assert(is_value_and_type(3.5 + t1, 14, LIGOTimeGPS))
 t2 -= 5.5
-assert(t2 == 5 and isinstance(t2, LIGOTimeGPS))
+assert(is_value_and_type(t2, 5, LIGOTimeGPS))
 assert(t2 + 5.5 >= t1 and t2 + 3 != t2)
-assert(t2 - 5 == t0 and isinstance(t2 - 5, LIGOTimeGPS))
-assert(t1 * 3 == 31.5 and isinstance(t1 * 3, LIGOTimeGPS))
-assert(3 * t1 == 31.5 and isinstance(3 * t1, LIGOTimeGPS))
+assert(is_value_and_type(t2 - 5, t0, LIGOTimeGPS))
+assert(is_value_and_type(t1 * 3, 31.5, LIGOTimeGPS))
+assert(is_value_and_type(3 * t1, 31.5, LIGOTimeGPS))
 if swig_division_coercion_works: # FIXME: https://github.com/swig/swig/pull/617
-    assert(t2 / 2.5 == 2 and isinstance(t2 / 2.5, LIGOTimeGPS))
-    assert(21 / t1  == 2 and isinstance(21 / t1, LIGOTimeGPS))
-assert(t1 + t2 == 15.5 and isinstance(t1 + t2, LIGOTimeGPS))
-assert(t1 - t2 == 5.5 and isinstance(t1 - t2, LIGOTimeGPS))
-assert(t1 * t2 == 52.5 and isinstance(t1 * t2, LIGOTimeGPS))
-assert(t2 * t1 == 52.5 and isinstance(t2 * t1, LIGOTimeGPS))
+    assert(is_value_and_type(t2 / 2.5, 2, LIGOTimeGPS))
+    assert(is_value_and_type(21 / t1, 2, LIGOTimeGPS))
+assert(is_value_and_type(t1 + t2, 15.5, LIGOTimeGPS))
+assert(is_value_and_type(t1 - t2, 5.5, LIGOTimeGPS))
+assert(is_value_and_type(t1 * t2, 52.5, LIGOTimeGPS))
+assert(is_value_and_type(t2 * t1, 52.5, LIGOTimeGPS))
 if swig_division_coercion_works: # FIXME: https://github.com/swig/swig/pull/617
-    assert(t1 / t2 == 2.1 and isinstance(t1 / t2, LIGOTimeGPS))
-assert(t1 % t2 == 0.5 and isinstance(t1 % t2, LIGOTimeGPS))
+    assert(is_value_and_type(t1 / t2, 2.1, LIGOTimeGPS))
+assert(is_value_and_type(t1 % t2, 0.5, LIGOTimeGPS))
 assert(t1 > t2 and t2 < t1 and t1 >= t2 and t2 <= t1)
 if swig_division_coercion_works: # FIXME: https://github.com/swig/swig/pull/617
     assert(LIGOTimeGPS(333333333,333333333) == LIGOTimeGPS(1000000000) / 3)
@@ -1056,8 +1074,9 @@ assert(LIGOTimeGPS("-6542354.389038577") == 7.1502318572066237 * LIGOTimeGPS("-9
 if swig_division_coercion_works: # FIXME: https://github.com/swig/swig/pull/617
     assert(LIGOTimeGPS("-127965.770535834") == LIGOTimeGPS("-914984.929117316") / 7.1502318572066237)
 t1 += 812345667.75
-assert(str(t1) == "812345678.250000000")
-assert(LIGOTimeGPS(repr(t1)) == t1)
+assert(str(t1) == "812345678.25")
+assert(type(eval(repr(t1))) is type(t1))
+assert(eval(repr(t1)) == t1)
 assert(int(t1) == 812345678)
 assert(t1.ns() == 812345678250000000)
 assert(hash(t1) == 1049484238)
@@ -1096,18 +1115,18 @@ class my_gps_class:
         self.gpsNanoSeconds = ns
 tmy = my_gps_class(987, 654321)
 tsw = LIGOTimeGPS(tmy)
-assert(isinstance(tsw, LIGOTimeGPS))
+assert(type(tsw) is LIGOTimeGPS)
 assert(tsw.gpsSeconds == 987)
 assert(tsw.gpsNanoSeconds == 654321)
-assert(tsw + tmy == tsw + tsw and isinstance(tsw + tmy, LIGOTimeGPS))
-assert(tmy + tsw == tsw + tsw and isinstance(tmy + tsw, LIGOTimeGPS))
-assert(tsw - tmy == tsw - tsw and isinstance(tsw - tmy, LIGOTimeGPS))
-assert(tmy - tsw == tsw - tsw and isinstance(tmy - tsw, LIGOTimeGPS))
-assert(tsw * tmy == tsw * tsw and isinstance(tsw * tmy, LIGOTimeGPS))
-assert(tmy * tsw == tsw * tsw and isinstance(tmy * tsw, LIGOTimeGPS))
+assert(is_value_and_type(tsw + tmy, tsw + tsw, LIGOTimeGPS))
+assert(is_value_and_type(tmy + tsw, tsw + tsw, LIGOTimeGPS))
+assert(is_value_and_type(tsw - tmy, tsw - tsw, LIGOTimeGPS))
+assert(is_value_and_type(tmy - tsw, tsw - tsw, LIGOTimeGPS))
+assert(is_value_and_type(tsw * tmy, tsw * tsw, LIGOTimeGPS))
+assert(is_value_and_type(tmy * tsw, tsw * tsw, LIGOTimeGPS))
 if swig_division_coercion_works: # FIXME: https://github.com/swig/swig/pull/617
-    assert(tsw / tmy == tsw / tsw and isinstance(tsw / tmy, LIGOTimeGPS))
-    assert(tmy / tsw == tsw / tsw and isinstance(tmy / tsw, LIGOTimeGPS))
+    assert(is_value_and_type(tsw / tmy, tsw / tsw, LIGOTimeGPS))
+    assert(is_value_and_type(tmy / tsw, tsw / tsw, LIGOTimeGPS))
 assert(lal.swig_lal_test_noptrgps(tmy) == lal.swig_lal_test_noptrgps(tsw))
 del tsw
 lal.CheckMemoryLeaks()
@@ -1116,14 +1135,14 @@ print("PASSED LIGOTimeGPS operations (Python specific)")
 # check LALUnit operations
 print("checking LALUnit operations ...")
 u1 = lal.Unit("kg m s^-2")
-assert(isinstance(lal.Unit(u1), lal.Unit))
-assert(u1 == lal.NewtonUnit and isinstance(u1, lal.Unit))
+assert(type(lal.Unit(u1)) is lal.Unit)
+assert(is_value_and_type(u1, lal.NewtonUnit, lal.Unit))
 assert(str(u1) == "m kg s^-2")
 if swig_division_coercion_works: # FIXME: https://github.com/swig/swig/pull/617
     u2 = lal.MeterUnit * lal.KiloGramUnit / lal.SecondUnit ** 2
-    assert(u1 == u2 and isinstance(u2, lal.Unit))
+    assert(is_value_and_type(u2, u1, lal.Unit))
 u2 = lal.MeterUnit**(1,2) * lal.KiloGramUnit**(1,2) * lal.SecondUnit ** -1
-assert(u1**(1,2) == u2 and isinstance(u2, lal.Unit))
+assert(is_value_and_type(u2, u1**(1,2), lal.Unit))
 try:
     lal.SecondUnit ** (1,0)
     expected_exception = True
@@ -1131,11 +1150,11 @@ except:
     pass
 assert(not expected_exception)
 u1 *= lal.MeterUnit
-assert(u1 == lal.JouleUnit and isinstance(u1, lal.Unit))
+assert(is_value_and_type(u1, lal.JouleUnit, lal.Unit))
 assert(repr(u1) == "m^2 kg s^-2")
 if swig_division_coercion_works: # FIXME: https://github.com/swig/swig/pull/617
     u1 /= lal.SecondUnit
-    assert(u1 == lal.WattUnit and isinstance(u1, lal.Unit))
+    assert(is_value_and_type(u1, lal.WattUnit, lal.Unit))
     assert(u1 == "m^2 kg s^-3")
     u1 *= 1000
     assert(u1 == lal.KiloUnit * lal.WattUnit)
